import { colorProps } from '@rndna/base_style';
import * as react_native from 'react-native';
import { TextInputProps, TextInput } from 'react-native';
import { SvgProps, NumberProp } from 'react-native-svg';
import React$1 from 'react';

type helperFieldType = "error" | "success" | "info" | "warning";
type variantType = "flat" | "filled" | "outlined";
interface IProps extends SvgProps {
    size?: NumberProp;
}
type assistiveTextType = {
    type: helperFieldType;
    message?: string;
    icon?: React.JSX.Element | ((e?: IProps | any) => React.JSX.Element);
};
type colorTypes = Exclude<colorProps, "primary" | "secondary" | "danger" | "default"> | "error";
type TextFieldtypes = Omit<TextInputProps, "onChange" | "editable"> & {
    /**
     * Sets the default value or state of the component (i.e activated or checked or prefilled).
     */
    value: string;
    /**
     * Property where the user can enable or disable the certain attribute or field.
     */
    disabled?: boolean;
    /**
     * Shows a descriptive text in a field before the field is typed in. Usually this will only be used in special need.
     */
    placeholder?: string;
    /**
     * Change Handler Callback and return text value
     */
    onChangeText?: (val: string) => void;
    /**
     * Change Handler Callback and return native event value
     */
    onChange?: (val: string) => void;
    /**
     * Property that enables user to select icon from the DNA icons library
     */
    icon?: React.JSX.Element | ((e?: IProps | any) => React.JSX.Element);
    /**
     * Property that makes all the inputted values cleared.
     */
    clearable?: boolean;
    /**
     * Display any assistive object or array of messages under the component (e.g. Warning or Error, etc.)
     */
    assistiveText?: assistiveTextType;
    /**
     * Property that shows the field is mandatory to be filled before submitting.
     */
    required?: boolean;
    /**
     * Changes the variation of the element. (flat, outlined, filled)
     */
    variant?: variantType;
    /**
     * Defines the string to prefix the value in textfield.
     */
    prefix?: string;
};

/**
 * default animation config for label / placeholder
 */
/**
 * A TextField is a component of the most generic and common data entry fields used to capture text type data—letters, numbers, and symbols..
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { View, Text } from 'react-native';
 * import { DNATextfield } from '@rndna/textfield';
 *
 * const ComponentName = () => {
 *
 * const [value, setValue] = useState('')
 * <DNATextfield
 *  value={value}
 *  onChangeText={(text) => {setValue(text)}}
 *  variant='flat' //flat | filled | outlined
 * />
 * }
 *
 * export default ComponentName;
 * ```
 */
declare const TextField: React$1.ForwardRefExoticComponent<Omit<react_native.TextInputProps, "onChange" | "editable"> & {
    value: string;
    disabled?: boolean | undefined;
    placeholder?: string | undefined;
    onChangeText?: ((val: string) => void) | undefined;
    onChange?: ((val: string) => void) | undefined;
    icon?: React$1.JSX.Element | ((e?: any) => React$1.JSX.Element) | undefined;
    clearable?: boolean | undefined;
    assistiveText?: assistiveTextType | undefined;
    required?: boolean | undefined;
    variant?: variantType | undefined;
    prefix?: string | undefined;
} & React$1.RefAttributes<TextInput>>;

export { TextField as DNATextField, type TextFieldtypes, type assistiveTextType, type colorTypes, type helperFieldType, type variantType };
